#define     tag a
Name:       ccache
Version:    4.9.1
Release:    %mkrel 1
Group:      Development/Other
Summary:    Compiler Cache
License:    GPLv3+
URL:        https://ccache.dev/
Source0:    https://github.com/ccache/ccache/releases/download/v%{version}/%{name}-%{version}%{?tag}.tar.xz

BuildRequires: cmake
BuildRequires: asciidoc
BuildRequires: docbook-style-xsl
BuildRequires: lib64zstd-devel
BuildRequires: lib64hiredis-devel

%description
ccache is a compiler cache. It acts as a caching pre-processor to
C/C++ compilers, using the -E compiler switch and a hash to detect
when a compilation can be satisfied from cache. This often results
in a 5 to 10 times speedup in common compilations.

The cache folder is now in ~/.cache/ccache. The old cache folder
in ~/ccache folder can be deleted.


%prep
%setup -q
# This fixes a cmake error
sed -i -e '/^\(string.STRIP\)/s/^/#/' cmake/CIBuildType.cmake

%build
%cmake
%cmake_build

cat <<EOF > %{name}.sh

if [ -f /etc/sysconfig/ccache ]; then
    . /etc/sysconfig/ccache
fi
if [ "\$USE_CCACHE_DEFAULT" = "yes" ]; then
    if [ -z \`echo "\$PATH" | grep "%_libdir/ccache/bin"\` ]; then
        export PATH="%_libdir/ccache/bin:\$PATH"
    fi
fi
EOF

cat << EOF > %{name}.csh

if ( -f /etc/sysconfig/ccache ) then
    eval \`sed -n 's/^\([^#]*\)=\([^#]*\)/set \1=\2;/p' < /etc/sysconfig/ccache\`
endif
if ( "\$USE_CCACHE_DEFAULT" == "yes" ) then
    if ( "\$path" !~ *%_libdir/ccache/bin* ) then
        setenv path = ( %_libdir/ccache/bin \$path )
    endif
endif
EOF

%install
%cmake_install
install -dm 755 %{buildroot}{%{_bindir},%{_libdir}/ccache/bin,%{_mandir}/man1}
install -dm 755 %{buildroot}%{_sysconfdir}/profile.d
install -pm 755 build/%{name}.sh %{buildroot}%{_sysconfdir}/profile.d
install -pm 755 build/%{name}.csh %{buildroot}%{_sysconfdir}/profile.d
rm -f %{name}-%{version}.compilers
pref=`gcc -dumpmachine`

create_compiler() {
cat <<EOF > %{buildroot}%{_prefix}/%{_lib}/ccache/bin/$1
#!/bin/sh
if [ ! -x %_bindir/$1 ]; then
    echo Error: compiler $1 does not exist. >&2
    exit 127
fi
PATH=%_bindir:\$PATH
if [ -f /etc/sysconfig/ccache ]; then
    . /etc/sysconfig/ccache
    if [ "\$USE_CCACHE_WITH_ICECREAM" = "yes" ]; then
    PATH=%{_libdir}/icecc/bin:\$PATH
    fi
fi

ccache ${1} "\$@"
EOF
echo "%attr(0755,root,root) %{_libdir}/ccache/bin/$1" >> %{name}-%{version}.compilers
}

for name in gcc g++ c++ clang clang++; do
 for comp in $name $pref-$name ${pref/manbo/mandriva}-$name; do
  # check for backports that have no manbo:
  [ -e "%{buildroot}%{_libdir}/ccache/bin/$comp" ] || create_compiler $comp
 done
done
create_compiler cc

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/
cat <<EOF > %{buildroot}/%{_sysconfdir}/sysconfig/%{name}
# Should we add the ccache compiler symlinks to PATH
# yes|no
# Please note that if added to \$PATH the user can still disable
# it with CCACHE_DISABLE
# If not enabled by default, the user can add %{_libdir}/ccache/bin/
# to their \$PATH
USE_CCACHE_DEFAULT="yes"

# Enable icecream integration
USE_CCACHE_WITH_ICECREAM="no"

EOF

%files -f %{name}-%{version}.compilers
%dir %{_libdir}/ccache
%dir %{_libdir}/ccache/bin
%{_bindir}/ccache
%{_sysconfdir}/profile.d/*
%config(noreplace) %{_sysconfdir}/sysconfig/*
%{_mandir}


%changelog
* Tue Feb 13 2024 tex - 4.9.1-1pclos2024
- new version

* Wed Jan 03 2024 tex - 4.9-1pclos2024
- new version

* Wed Sep 13 2023 tex - 4.8.3-1pclos2023
- new version

* Tue Jun 13 2023 tex - 4.8.2-1pclos2023
- new version

* Sat May 27 2023 tex - 4.8.1-1pclos2023
- new version

* Mon Mar 13 2023 tex - 4.8-1pclos2023
- new version

* Tue Nov 22 2022 tex - 4.7.4-1pclos2022
- new version

* Sun Nov 06 2022 tex - 4.7.3-1pclos2022
- new version

* Sat Oct 29 2022 tex - 4.7.2-1pclos2022
- new version

* Thu Oct 27 2022 tex - 4.7.1-1pclos2022
- new version

* Sun Aug 28 2022 tex - 4.6.3-1pclos2022
- new version

* Tue Aug 23 2022 tex - 4.6.2-1pclos2022
- new version

* Wed May 18 2022 tex - 4.6.1-1pclos2022
- new version

* Mon Feb 28 2022 tex - 4.6-1pclos2022
- new version

* Thu Nov 18 2021 tex - 4.5.1-1pclos2021
- new version

* Mon Nov 15 2021 tex - 4.5-1pclos2021
- new version

* Fri Oct 01 2021 tex - 4.4.2-1pclos2021
- new version

* Sun Aug 29 2021 tex - 4.4-1pclos2021
- new version

* Thu May 13 2021 tex - 4.3-1pclos2021
- new version

* Tue Apr 27 2021 tex - 4.2.1-1pclos2021
- new version

* Fri Jan 01 2021 tex - 4.1-1pclos2020
- new version
- The format and location of the cache is changed, so old cache directories
- should be deleted

